
var PanelLayer = cc.LayerColor.extend({
    parentLayer: null
});


var GameBoardLayer = cc.LayerColor.extend({

    ctor:function () {
        //////////////////////////////
        // 1. super init first
        // this._super();
        this._super(cc.color.WHITE);
    }
});


var GameScene = cc.Scene.extend({
    panelHeight:0,
    gameBoard: null,
    gameOverMenu: null,
    pauseMenu: null,
    scoresLabel: null,

    pauseGameWrap: function() {
        window.gameScene.pauseGame();
    },

    resumeGameWrap: function() {
        window.gameScene.resumeGame();
    },

    pauseGame: function() {
        this.addChild(this.pauseMenu);
        this.gameBoard.pauseGame();
    },

    playAgain: function() {
        cc.log("playAgain");
        window.gameScene.hideGameOverMenu();
        window.gameScene.startGame();
    },

    updateScores: function(scores) {
        this.scoresLabel.setString("SCORES: "+scores);
    },

    mainMenu: function() {
        cc.log("mainMenu");
        cc.director.popScene();
    },

    resumeGame: function() {
        cc.log("resumeGame");
        this.pauseMenu.removeFromParent();
        this.gameBoard.resumeGame();
    },

    startGame: function() {
        this.gameBoard.initBoard();
        this.runDontCrossLabel();
    },

    showGameOverMenu: function() {
        this.addChild(this.gameOverMenu);
    },
    hideGameOverMenu: function() {
        this.gameOverMenu.removeFromParent();
    },
    runDontCrossLabel: function() {
        this.lblDontCross.setPosition(cc.p(cc.winSize.width, this.gameBoard.panelHeight));
        var move_action = cc.MoveTo.create(8.0, cc.p(-this.lblDontCross.getContentSize().width, this.gameBoard.panelHeight));
        this.lblDontCross.runAction(move_action);
    },

    onEnter:function () {
        this._super();

// Basic layers (gameboard, top and bottom panels)        
        var ws = cc.winSize;
        var whiteBoard = new PanelLayer(cc.color(255, 255, 255, 255));

        whiteBoard.setContentSize(cc.size( ws.width, ws.height));
        this.panelHeight = (ws.height - ws.width)/2;

        var bottomPanel = new PanelLayer(cc.color(141, 198, 215, 255));
        bottomPanel.setContentSize(cc.size(ws.width, this.panelHeight));
        bottomPanel.setAnchorPoint(cc.p(0.0, 0.0));

        this.gameBoard = new GameBoardLayer(cc.color(255, 255, 255, 255));
        this.gameBoard.setAnchorPoint(cc.p(0.0, 0.0));
        this.gameBoard.setContentSize(cc.size(ws.width, ws.width));

        var topPanel = new PanelLayer(cc.color(141, 198, 215, 255));
        topPanel.setContentSize(cc.size(ws.width, this.panelHeight));
        topPanel.parentLayer = this;

        topPanel.setAnchorPoint(cc.p(0.0, 0.0));
        topPanel.setPosition(0.0, ws.height - topPanel.getContentSize().height);
        this.gameBoard.panelHeight = this.panelHeight;
        this.gameBoard.boardStartPosition = ws.height - bottomPanel.getContentSize().height;

        this.gameBoard.effectiveArea = cc.rect(topPanel.getPositionX(), bottomPanel.getContentSize().height,
            ws.width, ws.width);
        this.gameBoard.gameScene = this;


        this.addChild(whiteBoard);
        this.addChild(this.gameBoard);
        this.addChild(bottomPanel);
        this.addChild(topPanel);

        window.gameScene = this;
// Game Pause menu
        this.pauseMenu = new PanelLayer(cc.color(0, 0, 0, 200));
        this.pauseMenu.setContentSize(cc.size( ws.width, ws.height));
        var menuItem1 = new cc.MenuItemFont("Resume", this.resumeGameWrap);
        var menuItem2 = new cc.MenuItemFont("Restart", this.playAgain);
        var menuItem3 = new cc.MenuItemFont("Main menu", this.mainMenu);
        menuItem1.setPosition(cc.p(ws.width / 2, (ws.height / 4) * 3));
        menuItem2.setPosition(cc.p(ws.width / 2, (ws.height / 4) * 2));
        menuItem3.setPosition(cc.p(ws.width / 2, (ws.height / 4) * 1));
        var menu = new cc.Menu(menuItem1, menuItem2, menuItem3);
        menu.setPosition(cc.p(0, 0));
        this.pauseMenu.addChild(menu);


// GameOver menu
        this.gameOverMenu = new PanelLayer(cc.color(0, 0, 0, 200));
        this.gameOverMenu.setContentSize(cc.size( ws.width, ws.height));
        menuItem1 = new cc.MenuItemFont("Play again", this.playAgain);
        menuItem2 = new cc.MenuItemFont("Main menu", this.mainMenu);
        menuItem1.setPosition(cc.p(ws.width / 2, (ws.height / 3) * 2));
        menuItem2.setPosition(cc.p(ws.width / 2, (ws.height / 3) * 1));
        menu = new cc.Menu(menuItem1, menuItem2);
        menu.setPosition(cc.p(0, 0));
        this.gameOverMenu.addChild(menu);

// Pause button in top panel        
        menuItem1 = new cc.MenuItemFont("Pause", this.pauseGameWrap);        
        menuItem1.setPosition(cc.p(ws.width / 2, 0));
        menu = new cc.Menu(menuItem1);
        menu.setAnchorPoint(cc.p(1.0, 0.5));
        menu.setPosition(cc.p(topPanel.getContentSize().width/2 - 50, topPanel.getContentSize().height/2));
        topPanel.addChild(menu);


// Runnin hint line don't cross this line on game launch
        this.lblDontCross = new cc.LabelTTF("DO NOT CROSS THIS ↙ LINE", "Arial");
        this.lblDontCross.setFontSize(32);
        this.lblDontCross.setAnchorPoint(cc.p(0.0, 0.0));
        this.lblDontCross.setPosition(cc.p(ws.width, this.gameBoard.panelHeight));
        this.lblDontCross.setColor(cc.color(255, 0, 0));
        this.addChild(this.lblDontCross);        

// Scores and distance labels
        this.scoresLabel = new cc.LabelTTF("SCORES: 0", "Arial");
        this.scoresLabel.setAnchorPoint(cc.p(0.0, 0.5));
        this.scoresLabel.setFontSize(28);
        this.scoresLabel.setColor(cc.color(255, 255, 255));
        this.scoresLabel.setPosition(cc.p(10, topPanel.getContentSize().height * 3 / 4));
        topPanel.addChild(this.scoresLabel);
}
});
    